@@ -6,7 +6,7 @@
 -- For most users, "Network.HTTP.Simple" is probably a better choice. For more
 -- information, see:
 --
--- <https://github.com/commercialhaskell/jump/blob/master/doc/http-client.md>.
+-- <https://haskell-lang.org/library/http-client>
 --
 -- For more information on using this module, please be sure to read the
 -- documentation in the "Network.HTTP.Client" module.
@@ -49,7 +49,6 @@ import           Network.HTTP.Client          hiding (closeManager,
                                                newManager, responseClose,
                                                responseOpen, withManager,
                                                withResponse, BodyReader, brRead, brConsume, httpNoBody)
-import           Network.HTTP.Client          (HasHttpManager(..))
 import qualified Network.HTTP.Client          as H
 import           Network.HTTP.Client.TLS      (tlsManagerSettings)
 
